@@ -67,14 +67,14 @@ def save(filename, data):
 
 def save_append(filename, data1, data2):
     filename2 = filename
-    if os.path.isfile(filename):
-        n_of_files = len([name for name in os.listdir('.') if (os.path.isfile(name) and name==filename)])
-        filename2 = filename+'_'+str(n_of_files)
-        print(filename, ' already present. Saving it as ', filename2)
+#    if os.path.isfile(filename):
+#        n_of_files = len([name for name in os.listdir('.') if (os.path.isfile(name) and name==filename)])
+#        filename2 = filename+'_'+str(n_of_files)
+#        print(filename, ' already present. Saving it as ', filename2)
         
     file = open(filename2,'ab')
-    np.savetxt(filename2,data1)
-    np.savetxt(filename2,data2)
+    np.savetxt(file,data1)
+    np.savetxt(file,data2)
     file.close()
     return
 
